==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MooreStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;

import java.util.Arrays;
import java.util.List;


public class MooreStateMachineSetImpl extends InstanceSet<MooreStateMachineSet,MooreStateMachine> implements MooreStateMachineSet {

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MooreStateMachine moorestatemachine : this ) moorestatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R510_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( MooreStateMachine moorestatemachine : this ) sm_smset.add( moorestatemachine.R510_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( MooreStateMachine moorestatemachine : this ) mooreactionhomeset.addAll( moorestatemachine.R511_MooreActionHome() );
        return mooreactionhomeset;
    }


    @Override
    public MooreStateMachine nullElement() {
        return MooreStateMachineImpl.EMPTY_MOORESTATEMACHINE;
    }

    @Override
    public MooreStateMachineSet emptySet() {
      return new MooreStateMachineSetImpl();
    }

    @Override
    public MooreStateMachineSet value() {
        return this;
    }

    @Override
    public List<MooreStateMachine> elements() {
        return Arrays.asList(toArray(new MooreStateMachine[0]));
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/statemachine/impl/MooreStateMachineSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.statemachine.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreActionHomeSet;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachine;
import io.ciera.tool.sql.ooaofooa.statemachine.MooreStateMachineSet;
import io.ciera.tool.sql.ooaofooa.statemachine.SM_SMSet;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.MooreActionHomeSetImpl;
import io.ciera.tool.sql.ooaofooa.statemachine.impl.SM_SMSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class MooreStateMachineSetImpl extends InstanceSet<MooreStateMachineSet,MooreStateMachine> implements MooreStateMachineSet {

    public MooreStateMachineSetImpl() {
    }

    public MooreStateMachineSetImpl(Comparator<? super MooreStateMachine> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setSM_ID( UniqueId ref_SM_ID ) throws XtumlException {
        for ( MooreStateMachine moorestatemachine : this ) moorestatemachine.setSM_ID( ref_SM_ID );
    }


    // selections
    @Override
    public SM_SMSet R510_is_a_SM_SM() throws XtumlException {
        SM_SMSet sm_smset = new SM_SMSetImpl();
        for ( MooreStateMachine moorestatemachine : this ) sm_smset.add( moorestatemachine.R510_is_a_SM_SM() );
        return sm_smset;
    }
    @Override
    public MooreActionHomeSet R511_MooreActionHome() throws XtumlException {
        MooreActionHomeSet mooreactionhomeset = new MooreActionHomeSetImpl();
        for ( MooreStateMachine moorestatemachine : this ) mooreactionhomeset.addAll( moorestatemachine.R511_MooreActionHome() );
        return mooreactionhomeset;
    }


    @Override
    public MooreStateMachine nullElement() {
        return MooreStateMachineImpl.EMPTY_MOORESTATEMACHINE;
    }

    @Override
    public MooreStateMachineSet emptySet() {
      return new MooreStateMachineSetImpl();
    }

    @Override
    public MooreStateMachineSet emptySet(Comparator<? super MooreStateMachine> comp) {
      return new MooreStateMachineSetImpl(comp);
    }

    @Override
    public MooreStateMachineSet value() {
        return this;
    }

    @Override
    public List<MooreStateMachine> elements() {
        return Arrays.asList(toArray(new MooreStateMachine[0]));
    }

}
